import json
from typing import List, Optional

import requests

API_URL = "https://www.api.experiment-hq.com/"


class Experiment:
    """
    Experiment class for logging parameters to Notion.

    args:
        api_key (str): API key for the ExperimentHQ API
        project (str): Name of the project to log to
        name (Optional[str]): Name of the experiment
        description (Optional[str]): Description of the experiment
        tags (Optional[List[str]]): List of tags to add to the experiment
    """

    def __init__(
        self,
        api_key: str,
        project: str,
        name: Optional[str] = None,
        description: Optional[str] = None,
        tags: Optional[List[str]] = None,
    ):
        self.project = project
        self.api_key = api_key
        self.name = name
        self.description = description
        self.tags = tags
        self.experiment_id = self._start_experiment()

    def _start_experiment(self) -> str:
        post_data = {
            "project": self.project,
            "name": self.name,
            "description": self.description,
            "tags": self.tags,
        }
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}",
        }
        response = requests.post(
            url=f"{API_URL}experiment", data=json.dumps(post_data), headers=headers
        )
        if response.status_code != 200:
            raise Exception("Failed to start experiment with message: " + response.text)

        response_json = response.json()
        return response_json.get("experiment_id")

    def log_parameter(self, name: str, value: str) -> None:
        data = {"parameter_name": name, "parameter_value": value}
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {self.api_key}",
        }

        response = requests.post(
            url=f"{API_URL}experiments/{self.experiment_id}/parameters",
            data=json.dumps(data),
            headers=headers,
        )
        if response.status_code != 200:
            raise Exception("Failed to log parameter with message: " + response.text)



#!/usr/bin/env python

import os
import re
from glob import glob
from os.path import basename, splitext
from pathlib import Path

from setuptools import find_packages, setup  # type: ignore

# TODO: Update the package meta-data
NAME = "experimenthq"
MAIN_PACKAGE = "experimenthq"
DESCRIPTION = "A Python package for tracking experiments in Notion"
URL = "https://github.com/EperimentHQ/experiment-hq"
EMAIL = ""
AUTHOR = ""
LICENSE = "MIT"
REQUIRES_PYTHON = ">=3.7"
VERSION = None  # Only set version if you like to overwrite the version in _about.py
WEBSITE = "https://ml-notion-tracking-ui-vs3h.vercel.app/"


PWD = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

# Extract the version from the _about.py module.
if not VERSION:
    with open(os.path.join(PWD, "src", MAIN_PACKAGE, "_about.py")) as f:  # type: ignore
        VERSION = re.findall(r"__version__\s*=\s*\"(.+)\"", f.read())[0]

# Where the magic happens:
setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    license=LICENSE,
    packages=find_packages(where="src", exclude=("tests", "test", "examples", "docs")),
    package_dir={"": "src"},
    py_modules=[splitext(basename(path))[0] for path in glob("src/*.py")],
    zip_safe=False,
    install_requires=["requests", "types-requests"],
    extras_require={
        # extras can be installed via: pip install package[dev]
        "dev": [
            "pytest",
            "pytest-cov",
            "flake8",
            "black",
            "isort",
            "mypy",
            "twine",
            "wheel",
            "setuptools",
            "build",
            "colorama",
            "types-requests",
        ],
    },
    include_package_data=True,
    package_data={
        # If there are data files included in your packages that need to be
        # 'sample': ['package_data.dat'],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Natural Language :: English",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Information Technology",
        "Topic :: Scientific/Engineering",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Utilities",
    ],
    project_urls={
        "Changelog": URL + "/releases",
        "Issue Tracker": URL + "/issues",
        "Documentation": URL + "#documentation",
        "Source": URL,
        "Website": WEBSITE,
    },
    # entry_points={"console_scripts": [f"{NAME}={MAIN_PACKAGE}._cli:cli"]},
    keywords=[
        "notion",
        "tracking",
        "ml",
        "machine learning",
        "experiment",
        "experimentation",
        "experiment tracking",
        "python",
        "sync",
    ],
)
